@@ -57,23 +57,23 @@ func (j *Job) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 }
 
 // TailLogs tail logs for all pods represented by this Job.
-func (j *Job) TailLogs(ctx context.Context, c LogChan, opts *LogOptions) error {
+func (j *Job) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan, error) {
 	o, err := j.Factory.Get(j.gvr.String(), opts.Path, true, labels.Everything())
 	if err != nil {
-		return err
+		return nil, err
 	}
 
 	var job batchv1.Job
 	err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &job)
 	if err != nil {
-		return errors.New("expecting a job resource")
+		return nil, errors.New("expecting a job resource")
 	}
 
 	if job.Spec.Selector == nil || len(job.Spec.Selector.MatchLabels) == 0 {
-		return fmt.Errorf("No valid selector found on Job %s", opts.Path)
+		return nil, fmt.Errorf("No valid selector found on Job %s", opts.Path)
 	}
 
-	return podLogs(ctx, c, job.Spec.Selector.MatchLabels, opts)
+	return podLogs(ctx, job.Spec.Selector.MatchLabels, opts)
 }
 
 // ScanSA scans for serviceaccount refs.
