@@ -11,6 +11,7 @@ import (
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/rs/zerolog/log"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
@@ -25,7 +26,7 @@ type PortForward struct {
 }
 
 // Delete a portforward.
-func (p *PortForward) Delete(path string, cascade, force bool) error {
+func (p *PortForward) Delete(path string, _ *metav1.DeletionPropagation, force bool) error {
 	p.Factory.DeleteForwarder(path)
 
 	return nil
