@@ -8,8 +8,7 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/tview"
 	autoscalingv1 "k8s.io/api/autoscaling/v1"
-	autoscalingv2beta1 "k8s.io/api/autoscaling/v2beta1"
-	autoscalingv2beta2 "k8s.io/api/autoscaling/v2beta2"
+	autoscalingv2 "k8s.io/api/autoscaling/v2"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 )
@@ -46,10 +45,8 @@ func (h HorizontalPodAutoscaler) Render(o interface{}, ns string, r *Row) error
 	switch v {
 	case "autoscaling/v1":
 		return h.renderV1(raw, ns, r)
-	case "autoscaling/v2beta1":
-		return h.renderV2b1(raw, ns, r)
-	case "autoscaling/v2beta2":
-		return h.renderV2b2(raw, ns, r)
+	case "autoscaling/v2":
+		return h.renderV2(raw, ns, r)
 	default:
 		return fmt.Errorf("Unhandled HPA version %q", v)
 	}
@@ -78,8 +75,8 @@ func (h HorizontalPodAutoscaler) renderV1(raw *unstructured.Unstructured, _ stri
 	return nil
 }
 
-func (h HorizontalPodAutoscaler) renderV2b1(raw *unstructured.Unstructured, _ string, r *Row) error {
-	var hpa autoscalingv2beta1.HorizontalPodAutoscaler
+func (h HorizontalPodAutoscaler) renderV2(raw *unstructured.Unstructured, _ string, r *Row) error {
+	var hpa autoscalingv2.HorizontalPodAutoscaler
 	err := runtime.DefaultUnstructuredConverter.FromUnstructured(raw.Object, &hpa)
 	if err != nil {
 		return err
@@ -90,30 +87,7 @@ func (h HorizontalPodAutoscaler) renderV2b1(raw *unstructured.Unstructured, _ st
 		hpa.Namespace,
 		hpa.ObjectMeta.Name,
 		hpa.Spec.ScaleTargetRef.Name,
-		toMetricsV2b1(hpa.Spec.Metrics, hpa.Status.CurrentMetrics),
-		strconv.Itoa(int(*hpa.Spec.MinReplicas)),
-		strconv.Itoa(int(hpa.Spec.MaxReplicas)),
-		strconv.Itoa(int(hpa.Status.CurrentReplicas)),
-		"",
-		toAge(hpa.ObjectMeta.CreationTimestamp),
-	}
-
-	return nil
-}
-
-func (h HorizontalPodAutoscaler) renderV2b2(raw *unstructured.Unstructured, _ string, r *Row) error {
-	var hpa autoscalingv2beta2.HorizontalPodAutoscaler
-	err := runtime.DefaultUnstructuredConverter.FromUnstructured(raw.Object, &hpa)
-	if err != nil {
-		return err
-	}
-
-	r.ID = client.MetaFQN(hpa.ObjectMeta)
-	r.Fields = Fields{
-		hpa.Namespace,
-		hpa.ObjectMeta.Name,
-		hpa.Spec.ScaleTargetRef.Name,
-		toMetricsV2b2(hpa.Spec.Metrics, hpa.Status.CurrentMetrics),
+		toMetricsV2(hpa.Spec.Metrics, hpa.Status.CurrentMetrics),
 		strconv.Itoa(int(*hpa.Spec.MinReplicas)),
 		strconv.Itoa(int(hpa.Spec.MaxReplicas)),
 		strconv.Itoa(int(hpa.Status.CurrentReplicas)),
@@ -140,30 +114,7 @@ func toMetricsV1(spec autoscalingv1.HorizontalPodAutoscalerSpec, status autoscal
 	return current + "/" + target + "%"
 }
 
-func toMetricsV2b1(specs []autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
-	if len(specs) == 0 {
-		return MissingValue
-	}
-
-	list := make([]string, 0, len(specs))
-	for i, spec := range specs {
-		list = append(list, checkHPAType(i, spec, statuses))
-	}
-
-	max, more := 10, false
-	if len(list) > max {
-		list, more = list[:max], true
-	}
-
-	ret := strings.Join(list, ", ")
-	if more {
-		return ret + " + " + strconv.Itoa(len(list)-max) + "more..."
-	}
-
-	return ret
-}
-
-func toMetricsV2b2(specs []autoscalingv2beta2.MetricSpec, statuses []autoscalingv2beta2.MetricStatus) string {
+func toMetricsV2(specs []autoscalingv2.MetricSpec, statuses []autoscalingv2.MetricStatus) string {
 	if len(specs) == 0 {
 		return MissingValue
 	}
@@ -174,20 +125,20 @@ func toMetricsV2b2(specs []autoscalingv2beta2.MetricSpec, statuses []autoscaling
 
 		// nolint:exhaustive
 		switch spec.Type {
-		case autoscalingv2beta2.ExternalMetricSourceType:
-			list = append(list, externalMetricsV2b2(i, spec, statuses))
-		case autoscalingv2beta2.PodsMetricSourceType:
+		case autoscalingv2.ExternalMetricSourceType:
+			list = append(list, externalMetricsV2(i, spec, statuses))
+		case autoscalingv2.PodsMetricSourceType:
 			if len(statuses) > i && statuses[i].Pods != nil {
 				current = statuses[i].Pods.Current.AverageValue.String()
 			}
 			list = append(list, current+"/"+spec.Pods.Target.AverageValue.String())
-		case autoscalingv2beta2.ObjectMetricSourceType:
+		case autoscalingv2.ObjectMetricSourceType:
 			if len(statuses) > i && statuses[i].Object != nil {
 				current = statuses[i].Object.Current.Value.String()
 			}
 			list = append(list, current+"/"+spec.Object.Target.Value.String())
-		case autoscalingv2beta2.ResourceMetricSourceType:
-			list = append(list, resourceMetricsV2b2(i, spec, statuses))
+		case autoscalingv2.ResourceMetricSourceType:
+			list = append(list, resourceMetricsV2(i, spec, statuses))
 		default:
 			list = append(list, "<unknown type>")
 		}
@@ -206,31 +157,31 @@ func toMetricsV2b2(specs []autoscalingv2beta2.MetricSpec, statuses []autoscaling
 	return ret
 }
 
-func checkHPAType(i int, spec autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
+func checkHPAType(i int, spec autoscalingv2.MetricSpec, statuses []autoscalingv2.MetricStatus) string {
 	current := "<unknown>"
 
 	// nolint:exhaustive
 	switch spec.Type {
-	case autoscalingv2beta1.ExternalMetricSourceType:
-		return externalMetricsV2b1(i, spec, statuses)
-	case autoscalingv2beta1.PodsMetricSourceType:
+	case autoscalingv2.ExternalMetricSourceType:
+		return externalMetricsV2(i, spec, statuses)
+	case autoscalingv2.PodsMetricSourceType:
 		if len(statuses) > i && statuses[i].Pods != nil {
-			current = statuses[i].Pods.CurrentAverageValue.String()
+			current = statuses[i].Pods.Current.AverageValue.String()
 		}
-		return current + "/" + spec.Pods.TargetAverageValue.String()
-	case autoscalingv2beta1.ObjectMetricSourceType:
+		return current + "/" + spec.Pods.Target.AverageValue.String()
+	case autoscalingv2.ObjectMetricSourceType:
 		if len(statuses) > i && statuses[i].Object != nil {
-			current = statuses[i].Object.CurrentValue.String()
+			current = statuses[i].Object.Current.Value.String()
 		}
-		return current + "/" + spec.Object.TargetValue.String()
-	case autoscalingv2beta1.ResourceMetricSourceType:
-		return resourceMetricsV2b1(i, spec, statuses)
+		return current + "/" + spec.Object.Target.Value.String()
+	case autoscalingv2.ResourceMetricSourceType:
+		return resourceMetricsV2(i, spec, statuses)
 	}
 
 	return "<unknown type>"
 }
 
-func externalMetricsV2b2(i int, spec autoscalingv2beta2.MetricSpec, statuses []autoscalingv2beta2.MetricStatus) string {
+func externalMetricsV2(i int, spec autoscalingv2.MetricSpec, statuses []autoscalingv2.MetricStatus) string {
 	current := "<unknown>"
 
 	if spec.External.Target.AverageValue != nil {
@@ -246,7 +197,7 @@ func externalMetricsV2b2(i int, spec autoscalingv2beta2.MetricSpec, statuses []a
 	return current + "/" + spec.External.Target.Value.String()
 }
 
-func resourceMetricsV2b2(i int, spec autoscalingv2beta2.MetricSpec, statuses []autoscalingv2beta2.MetricStatus) string {
+func resourceMetricsV2(i int, spec autoscalingv2.MetricSpec, statuses []autoscalingv2.MetricStatus) string {
 	current := "<unknown>"
 
 	if spec.Resource.Target.AverageValue != nil {
@@ -268,48 +219,48 @@ func resourceMetricsV2b2(i int, spec autoscalingv2beta2.MetricSpec, statuses []a
 	return current + "/" + target
 }
 
-func externalMetricsV2b1(i int, spec autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
-	current := "<unknown>"
-	if spec.External.TargetAverageValue != nil {
-		if len(statuses) > i && statuses[i].External != nil && statuses[i].External.CurrentAverageValue != nil {
-			current = statuses[i].External.CurrentAverageValue.String()
-		}
-		return current + "/" + spec.External.TargetAverageValue.String() + " (avg)"
-	}
-	if len(statuses) > i && statuses[i].External != nil {
-		current = statuses[i].External.CurrentValue.String()
-	}
+// func externalMetricsV2b1(i int, spec autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
+// 	current := "<unknown>"
+// 	if spec.External.TargetAverageValue != nil {
+// 		if len(statuses) > i && statuses[i].External != nil && statuses[i].External.CurrentAverageValue != nil {
+// 			current = statuses[i].External.CurrentAverageValue.String()
+// 		}
+// 		return current + "/" + spec.External.TargetAverageValue.String() + " (avg)"
+// 	}
+// 	if len(statuses) > i && statuses[i].External != nil {
+// 		current = statuses[i].External.CurrentValue.String()
+// 	}
 
-	return current + "/" + spec.External.TargetValue.String()
-}
+// 	return current + "/" + spec.External.TargetValue.String()
+// }
 
-func resourceMetricsV2b1(i int, spec autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
-	current := "<unknown>"
+// func resourceMetricsV2b1(i int, spec autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
+// 	current := "<unknown>"
 
-	if status := checkTargetMetricsV2b1(i, spec, statuses); status != "" {
-		return status
-	}
+// 	if status := checkTargetMetricsV2b1(i, spec, statuses); status != "" {
+// 		return status
+// 	}
 
-	if len(statuses) > i && statuses[i].Resource != nil && statuses[i].Resource.CurrentAverageUtilization != nil {
-		current = IntToStr(int(*statuses[i].Resource.CurrentAverageUtilization))
-	}
+// 	if len(statuses) > i && statuses[i].Resource != nil && statuses[i].Resource.CurrentAverageUtilization != nil {
+// 		current = IntToStr(int(*statuses[i].Resource.CurrentAverageUtilization))
+// 	}
 
-	target := "<auto>"
-	if spec.Resource.TargetAverageUtilization != nil {
-		target = IntToStr(int(*spec.Resource.TargetAverageUtilization))
-	}
+// 	target := "<auto>"
+// 	if spec.Resource.TargetAverageUtilization != nil {
+// 		target = IntToStr(int(*spec.Resource.TargetAverageUtilization))
+// 	}
 
-	return current + "/" + target
-}
+// 	return current + "/" + target
+// }
 
-func checkTargetMetricsV2b1(i int, spec autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
-	if spec.Resource.TargetAverageValue == nil {
-		return ""
-	}
+// func checkTargetMetricsV2b1(i int, spec autoscalingv2beta1.MetricSpec, statuses []autoscalingv2beta1.MetricStatus) string {
+// 	if spec.Resource.TargetAverageValue == nil {
+// 		return ""
+// 	}
 
-	var current string
-	if len(statuses) > i && statuses[i].Resource != nil {
-		current = statuses[i].Resource.CurrentAverageValue.String()
-	}
-	return current + "/" + spec.Resource.TargetAverageValue.String()
-}
+// 	var current string
+// 	if len(statuses) > i && statuses[i].Resource != nil {
+// 		current = statuses[i].Resource.CurrentAverageValue.String()
+// 	}
+// 	return current + "/" + spec.Resource.TargetAverageValue.String()
+// }
