@@ -195,6 +195,10 @@ func (r RowEvents) FindIndex(id string) (int, bool) {
 	return 0, false
 }
 
+type tuple struct {
+	field, id string
+}
+
 // Sort rows based on column index and order.
 func (r RowEvents) Sort(ns string, sortCol int, isDuration, numCol, asc bool) {
 	if sortCol == -1 {
@@ -210,24 +214,6 @@ func (r RowEvents) Sort(ns string, sortCol int, isDuration, numCol, asc bool) {
 		IsDuration: isDuration,
 	}
 	sort.Sort(t)
-
-	iids, fields := map[string][]string{}, make(StringSet, 0, len(r))
-	for _, re := range r {
-		field := re.Row.Fields[sortCol]
-		if isDuration {
-			field = toAgeDuration(field)
-		}
-		fields = fields.Add(field)
-		iids[field] = append(iids[field], re.Row.ID)
-	}
-
-	ids := make([]string, 0, len(r))
-	for _, field := range fields {
-		sort.StringSlice(iids[field]).Sort()
-		ids = append(ids, iids[field]...)
-	}
-	s := IdSorter{Ids: ids, Events: r}
-	sort.Sort(s)
 }
 
 // ----------------------------------------------------------------------------
@@ -252,7 +238,8 @@ func (r RowEventSorter) Swap(i, j int) {
 
 func (r RowEventSorter) Less(i, j int) bool {
 	f1, f2 := r.Events[i].Row.Fields, r.Events[j].Row.Fields
-	return Less(r.Asc, r.IsNumber, r.IsDuration, f1[r.Index], f2[r.Index])
+	id1, id2 := r.Events[i].Row.ID, r.Events[j].Row.ID
+	return Less(r.Asc, r.IsNumber, r.IsDuration, id1, id2, f1[r.Index], f2[r.Index])
 }
 
 // ----------------------------------------------------------------------------
